srtk.entity\_linking package
=============================


srtk.entity\_linking.linker\_base module
-----------------------------------------

By extending ``LinkerBase``, you can easily generalize ``srtk.linker`` to other knowledge graphs.

.. automodule:: srtk.entity_linking.linker_base
   :members:
   :undoc-members:
   :show-inheritance:

srtk.entity\_linking.wikidata module
----------------------------------------

.. automodule:: srtk.entity_linking.wikidata
   :members:
   :undoc-members:
   :show-inheritance:

srtk.entity\_linking.dbpedia module
-------------------------------------

.. automodule:: srtk.entity_linking.dbpedia
   :members:
   :undoc-members:
   :show-inheritance:
